﻿© Fluke. All Rights Reserved.                               MET/CAL Procedure
=============================================================================
INSTRUMENT:            Sub FSU Take Sweep Only
INSTRUMENT:            Sub FSU Take Sweep (MKF)
INSTRUMENT:            Sub FSU Take Sweep (MKCF)
INSTRUMENT:            Sub FSU Take Sweep (MKPK)
INSTRUMENT:            Sub FSU Take Sweep (MKPK, MKCF)
DATE:                  2011-01-14
AUTHOR:                Fluke Calibration
REVISION:              $Revision: 2619 $
ADJUSTMENT THRESHOLD:  70%
NUMBER OF TESTS:       6
NUMBER OF LINES:       205
=============================================================================
#
#  Procedure Author:
#        DFM
#
#  Model(s) Covered:
#        Rohde & Schwarz FSU series
#
#  Compatibility:
#        MET/CAL 7.20x or later
#
#  Subprocedures:
#        None
#
#  Required Files:
#        None
#
#  Additional Equipment Required:
#        None
#
#  The copyright for this procedure is owned by Fluke Corporation.
#
 STEP    FSC    RANGE NOMINAL        TOLERANCE     MOD1        MOD2  3  4 CON

# Set number of sweeps.
  1.001  MATH         Sweeps = 2

  1.002  JMPL         SWEEP                        PSUBI("Only")
  1.003  JMPL         MKF                          PSUBI("(MKF)")
  1.004  JMPL         MKCF                         PSUBI("(MKCF)")
  1.005  JMPL         MKPK                         PSUBI("(MKPK)")
  1.006  JMPL         MKPK_MKCF                    PSUBI("(MKPK, MKCF)")
  1.007  DISP         Called {Subprocedure Not Found}!
  1.008  END

  1.009  EVAL   Increment Test Number

# ====== Sub FSU Take Sweep Only ===========================================
#
# This sub takes two sweeps and does not alter the marker, center frequency,
# or any other UUT settings.
#
#  Example:
# 1.001  CALL         Sub FSU Take Sweep Only

  2.001  LABEL        SWEEP

  2.002  WHILE        Sweeps > 0
  2.003  SCPI         [T60000]INIT:IMM
# Decrement sweep counter by one.
  2.004  MATH         Sweeps = Sweeps - 1
  2.005  ENDW

  2.006  END

  2.007  EVAL   Increment Test Number

# ====== Sub FSU Take Sweep (MKF) ==========================================
#
# This sub takes two sweeps, placing the active marker at a frequency passed
# by the calling procedure after the second sweep.
#
#  Example:
# 1.001  MATH         @MarkerFreq = 1E+6
# 1.002  CALL         Sub FSU Take Sweep (MKF)

  3.001  LABEL        MKF

  3.002  WHILE        Sweeps > 0
  3.003  SCPI         [T60000]INIT:IMM
# Decrement sweep counter by one.
  3.004  MATH         Sweeps = Sweeps - 1
  3.005  ENDW

  3.006  IF           ISVAR("@MkrMode")

# If "Normal" marker type is specified, use "normal" marker peak mode.
  3.007  IF           ZCMPI(@MkrMode, "Normal")
  3.008  SCPI         CALC:MARK:X [V @MarkerFreq]
# If "Delta" marker type is specified, use "normal" marker peak mode.
  3.009  ELSEIF       ZCMPI(@MkrMode, "Delta")
  3.010  SCPI         CALC:DELT:X [V @MarkerFreq]
  3.011  ENDIF

# If no marker type is specified, use "normal" marker peak mode.
  3.012  ELSE
  3.013  SCPI         CALC:MARK:X [V @MarkerFreq]
  3.014  ENDIF

  3.015  END

  3.016  EVAL   Increment Test Number

# ====== Sub FSU Take Sweep (MKCF) =========================================
#
# This sub takes two sweeps, placing the active marker at center frequency
# on the display after each sweep.
#
#  Example:
# 1.001  CALL         Sub FSU Take Sweep (MKCF)

  4.001  LABEL        MKCF

  4.002  WHILE        Sweeps > 0
  4.003  SCPI         [T60000]INIT:IMM
# Set UUT marker to (highest) peak.
  4.004  SCPI         CALC:MARK:FUNC:CENT

# Decrement sweep counter by one.
  4.005  MATH         Sweeps = Sweeps - 1
  4.006  ENDW

  4.007  END

  4.008  EVAL   Increment Test Number

# ====== Sub FSU Take Sweep (MKPK) =========================================
#
# This sub takes two sweeps, placing the active marker at the highest peak
# present on the display after each sweep. Note that the active marker may
# be the "delta" marker, if previously specified in the calling procedure.
#
#  Example:
# 1.001  CALL         Sub FSU Take Sweep (MKPK)

  5.001  LABEL        MKPK

  5.002  WHILE        Sweeps > 0
  5.003  SCPI         [T60000]INIT:IMM

  5.004  IF           ISVAR("@MkrMode")

  5.005  IF           ZCMPI(@MkrMode, "Normal")
  5.006  SCPI         CALC:MARK:MAX
# If "Delta" marker type is specified, use "normal" marker peak mode.
  5.007  ELSEIF       ZCMPI(@MkrMode, "Delta")
  5.008  SCPI         CALC:DELT:MAX
  5.009  ENDIF

# If no marker type variable exists, use "normal" marker peak mode.
  5.010  ELSE
  5.011  SCPI         CALC:MARK:MAX
  5.012  ENDIF

# Set UUT marker to (highest) peak.

# Decrement sweep counter by one.
  5.013  MATH         Sweeps = Sweeps - 1
  5.014  ENDW

  5.015  END

  5.016  EVAL   Increment Test Number

# ====== Sub FSU Take Sweep (MKPK, MKCF) ===================================
#
# This sub takes two sweeps, placing the active marker at the highest peak
# present on the display, then moving the marker to the center frequency after
# each sweep. Note that the active marker may be the "delta" marker, if
# specified previously in the calling procedure.
#
#  Example:
# 1.001  CALL         Sub FSU Take Sweep (MKPK, MKCF)
#
# Note that this sub does NOT turn the UUT signal tracking on; that must be
# done, if desired, explicitly. In that case, it is preferred to accomplish
# the task as follows:
#
# 1.001  SCPI         CALC:MARK:FUNC:STR:STAT ON
# 1.002  CALL         Sub FSU Take Sweep (MKPK)
#
# Turning signal tracking on will automatically place the marker at the UUT
# center frequency, in addition to keeping it there if the UUT local
# oscillator drifts (quite common in some of the lower end 859x models).

  6.001  LABEL        MKPK_MKCF

  6.002  WHILE        Sweeps > 0
  6.003  SCPI         [T60000]INIT:IMM

# Set UUT marker to (highest) peak; move marker to center frequency.
  6.004  SCPI         CALC:MARK:MAX;:CALC:MARK:FUNC:CENTER

# Decrement sweep counter by one.
  6.005  MATH         Sweeps = Sweeps - 1
  6.006  ENDW

  6.007  END
